@@ -105,6 +105,7 @@ pub struct PTYArgs {
 /// use winptyrs::{PTY, PTYArgs, MouseMode, AgentConfig, PTYBackend};
 ///
 /// let cmd = OsString::from("c:\\windows\\system32\\cmd.exe");
+///
 /// let pty_args = PTYArgs {
 ///     cols: 80,
 ///     rows: 25,
@@ -114,8 +115,8 @@ pub struct PTYArgs {
 /// };
 ///
 /// // Initialize a winpty and a conpty pseudoterminal.
-/// let winpty = PTY::new_with_backend(&pty_args, PTYBackend::WinPTY).unwrap();
 /// let conpty = PTY::new_with_backend(&pty_args, PTYBackend::ConPTY).unwrap();
+/// let winpty = PTY::new_with_backend(&pty_args, PTYBackend::WinPTY).unwrap();
 /// ```
 pub struct PTY {
 	 /// Backend used by the current pseudoterminal, must be one of [`self::PTYBackend`].
@@ -263,7 +264,7 @@ impl PTY {
     /// # Returns
     /// `true` if the process reached EOL, false otherwise. If an error occurs, then a [`OsString`]
     /// containing a human-readable error is raised.
-    pub fn is_eof(&mut self) -> Result<bool, OsString> {
+    pub fn is_eof(&self) -> Result<bool, OsString> {
 		self.pty.is_eof()
     }
 
@@ -271,12 +272,12 @@ impl PTY {
     ///
     /// # Returns
     /// `None` if the process has not exited, else the exit code of the process.
-    pub fn get_exitstatus(&mut self) -> Result<Option<u32>, OsString> {
+    pub fn get_exitstatus(&self) -> Result<Option<u32>, OsString> {
         self.pty.get_exitstatus()
     }
 
 	/// Determine if the process is still alive.
-    pub fn is_alive(&mut self) -> Result<bool, OsString> {
+    pub fn is_alive(&self) -> Result<bool, OsString> {
         self.pty.is_alive()
     }
 
@@ -284,4 +285,9 @@ impl PTY {
 	pub fn get_pid(&self) -> u32 {
         self.pty.get_pid()
     }
+
+	/// Retrieve the process handle ID of the spawned program.
+	pub fn get_fd(&self) -> isize {
+		self.pty.get_fd()
+	}
 }
